@@ -19,12 +19,7 @@
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *    Author: Neil Brown
- *    Email: <neilb@cse.unsw.edu.au>
- *    Paper: Neil Brown
- *           School of Computer Science and Engineering
- *           The University of New South Wales
- *           Sydney, 2052
- *           Australia
+ *    Email: <neilb@suse.de>
  */
 
 /*
@@ -84,7 +79,7 @@ struct v {
  * We would like symetry in our answers so that a good sequence with an out-rider on
  * one end is evaluated the same as a good sequence with an out-rider on the other end.
  * However to do this we cannot really use value of the good sequence to weigh in the
- * outriders favour as in the case of a leading outrider, we do not yet know the value of 
+ * outriders favour as in the case of a leading outrider, we do not yet know the value of
  * of the good sequence.
  * First, we need an arbitrary number, X, to say "Given a single symbol, after X errors, we
  * forget that symbol".  5 seems a good number.
@@ -231,8 +226,8 @@ void find_best(struct file *a, struct file *b,
 #endif
 			v[klo].val = 0;
 		}
-		while (klo+2 < (ahi-bhi) && 
-		       (y > bhi || 
+		while (klo+2 < (ahi-bhi) &&
+		       (y > bhi ||
 			(best_val(&v[klo], min(ahi-x,bhi-y)) < best[v[klo].c].val &&
 			 best_val(&v[klo+1], min(ahi-x,bhi-y+1)) < best[v[klo+1].c].val
 				)
@@ -299,7 +294,7 @@ static void printword(struct elmnt e)
  * reduce a file by discarding less interesting words
  * Words that end with a newline are interesting (so all words
  * in line-mode are interesting) and words that start with
- * and alphanumeric are interesting.  This excludes spaces and 
+ * and alphanumeric are interesting.  This excludes spaces and
  * special characters in word mode
  * Doing a best-fit comparision on only interesting words is
  * much fast than on all words, and it nearly as good
@@ -307,7 +302,7 @@ static void printword(struct elmnt e)
 
 static inline int is_skipped(struct elmnt e)
 {
-	return !( ends_line(e) || 
+	return !( ends_line(e) ||
 		  isalnum(e.start[0]) ||
 		  e.start[0] == '_');
 }
@@ -346,7 +341,10 @@ void remap(struct best *best, int cnt,
 	int pa,pb;
 	pa=pb=0;
 
-	for (b=1; b<cnt; b++) {
+	if (a1.elcnt == 0 && a2.elcnt == 0) return;
+
+	for (b=1; b<cnt; b++)
+	   if (best[b].val>0) {
 #if 0
 		printf("best %d,%d  %d,%d\n",
 		       best[b].xlo,best[b].ylo,
@@ -362,7 +360,7 @@ void remap(struct best *best, int cnt,
 		if (pb == b2.elcnt) abort();
 
 		/* pa,pb is the start of this best bit.  Step
-		 * backward over ignored words 
+		 * backward over ignored words
 		 */
 		while (pa>0 && is_skipped(a2.list[pa-1]))
 			pa--;
@@ -462,7 +460,7 @@ struct csl *pdiff(struct file a, struct file b, int chunks)
 
 	for (i=0; i<chunks+1; i++)
 		best[i].val = 0;
-	find_best_inorder(&asmall,&bsmall, 
+	find_best_inorder(&asmall,&bsmall,
 		  0, asmall.elcnt, 0, bsmall.elcnt,
 		  best, 1, chunks+1);
 #if 0
